Class: Fastlane::Helper::GitlabBranchDiffHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::GitlabBranchDiffHelper
- Defined in:
- lib/fastlane/plugin/gitlab_branch_diff/helper/gitlab_branch_diff_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::GitlabBranchDiffHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action as Helper::GitlabBranchDiffHelper.your_method
11 12 13 |
# File 'lib/fastlane/plugin/gitlab_branch_diff/helper/gitlab_branch_diff_helper.rb', line 11 def self. UI.("Hello from the gitlab_branch_diff plugin helper!") end |